include <base.scad>;
include <servo/horn.scad>;
include <gimbal/config.scad>;

use <gimbal/gimbal.scad>; 
use <servo/sg9.scad>;
use <strengthen/servo.scad>;
use <base_plate/plate.scad>;



module battery() {
    color("blue")
        translate(battery_offset)
                translate([0, 0, -battery_dim[2]/2])
                    cube(battery_dim, center=true);
}

module raspbpi(){
    color("green")
    translate(rpi_offset)
    translate([11, 0, 0])
        import( "B+_Model_v4.stl" );
}


module tibia() {
    translate([-mg90s_turret_diameter/2, 0, 0])
    rotate([90, 0, -90])
        rotate([0, 0, 90]){
            mg90s();
            color("DarkGray")
            translate([0, 11, -4.5])
                rotate([0, 0, 90])
                    import("leg.stl");
        }
}

module femur(){
    
    translate([-mg90s_turret_diameter/2 - servo_horn_h - mg90s_turret_height, 0, 0])
    rotate([0, -90, 0]){
        rotate([0, 0, 90])
            horn();
        translate([0, femur_arm[1], 0])
            rotate([0 ,0, -90])
                horn();
    }
}

module coxa(){
    horn();

    translate([0, 0, -mg90s_horn_offset]){
        rotate([0, 0, 90])
            mg90s();
        translate(mg90s_gimbal_vector)
        rotate([90, 0, -90])
            rotate([0, 0, 180]) {
                mg90s();
            }
    }
}

module camera_pos(){
    trans_v = [rpi_offset[0] + rpi_holes_x/2, 0, 25];
    rot_v = [0, 0, 180];
    translate(trans_v)
        rotate(rot_v)
            children();
    
}

module axis(name, angle=[0,0,0]){
    color("yellow")
    rotate(angle)
    cylinder(d=2, h=50, center=true);
}

module arm(name, vector){
    
    color("Green")
        hull(){
        sphere(d=2);
        translate(vector)
            sphere(d=2);
    }
}

module kinematics(d=3){

    color("SeaGreen") hull(){ 
            leg_pos()
                sphere(d=d);
   
            camera_pos()
            translate([0, 0, camera_holder_t])
            sphere(d=d); 
    }

    camera_pos() translate(yaw_offset) { 
        axis("yaw");        
        arm("yaw",  pitch_offset );
       
        translate(  pitch_offset ){

            axis("pitch", [90, 0, 0]);
            arm("pitch", [camera_x_offset, -pitch_offset[1], 0]);

            color("blue", 0.3)
            translate([camera_x_offset, -pitch_offset[1], 0])
            rotate([0, 90, 0])
            cylinder(d1=1, d2=20, h=40);
        }

    }
    
    leg_pos(){

        arm("coxa", coxa_arm);
        axis("coxa");
         
        translate(coxa_arm){

            arm("femur", femur_arm);
            axis("femur", [0, 90, 0]);   
     
            translate(femur_arm){
                arm("tibia", tibia_arm); 
                axis("tibia", [0, 90, 0]); 
            }
        }
    }
    
}


module body(){
    color("gray")
        bottom_plate();

    battery();
    
    color("gray")
        translate([0, 0, -45])
            cross();
    
    translate([0, 0, 5]){
        raspbpi();
    }

    camera_pos()
        camera_base();

}

module model() {

    
kinematics();

    #union(){

        body();

        leg_pos(){
            coxa();
            translate(coxa_arm){
                femur();
                translate(femur_arm){
                    tibia();
                }
            }
        }

        camera_pos() translate(yaw_offset) {
            camera_yaw();
            translate(pitch_offset)
                camera_pitch();
        }

    }

}
